pub struct BitChord {
pub mask: PitchClassMask,
pub root: Option<PitchClass>,
}Expand description
A chord represented as a PitchClassMask with an optional designated root.
When root is None the chord is rootless and can be reduced to its
transposition-invariant normal form via BitChord::canonical.
Fields
mask: PitchClassMaskThe pitch classes that make up the chord.
root: Option<PitchClass>The chord root, or None for a rootless chord.
Implementations